darkhistory.spec.transferfunction.TransFuncAtEnergy
===================================================

.. currentmodule:: darkhistory.spec.transferfunction

.. autoclass:: TransFuncAtEnergy

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TransFuncAtEnergy.__init__
      ~TransFuncAtEnergy.append
      ~TransFuncAtEnergy.at_rs
      ~TransFuncAtEnergy.integrate_each_spec
      ~TransFuncAtEnergy.plot
      ~TransFuncAtEnergy.rebin
      ~TransFuncAtEnergy.redshift
      ~TransFuncAtEnergy.sum_specs
      ~TransFuncAtEnergy.switch_spec_type
      ~TransFuncAtEnergy.totN
      ~TransFuncAtEnergy.toteng
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TransFuncAtEnergy.N_underflow
      ~TransFuncAtEnergy.eng
      ~TransFuncAtEnergy.eng_underflow
      ~TransFuncAtEnergy.grid_vals
      ~TransFuncAtEnergy.in_eng
      ~TransFuncAtEnergy.rs
      ~TransFuncAtEnergy.spec_type
   
   